summaryrefslogtreecommitdiffstats
path: root/opengl/system/gralloc/gralloc.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'opengl/system/gralloc/gralloc.cpp')
-rw-r--r--opengl/system/gralloc/gralloc.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/opengl/system/gralloc/gralloc.cpp b/opengl/system/gralloc/gralloc.cpp
index 9659e3d..ef18511 100644
--- a/opengl/system/gralloc/gralloc.cpp
+++ b/opengl/system/gralloc/gralloc.cpp
@@ -212,10 +212,11 @@ static int gralloc_alloc(alloc_device_t* dev,
glType = GL_UNSIGNED_SHORT_5_6_5;
break;
case HAL_PIXEL_FORMAT_RAW16:
+ case HAL_PIXEL_FORMAT_Y16:
bpp = 2;
align = 16*bpp;
if (! ((sw_read || hw_cam_read) && (sw_write || hw_cam_write) ) ) {
// Raw sensor data only goes between camera and CPU
return -EINVAL;
}
// Not expecting to actually create any GL surfaces for this
@@ -212,10 +212,11 @@ static int gralloc_alloc(alloc_device_t* dev,
align = 16*bpp;
if (! ((sw_read || hw_cam_read) && (sw_write || hw_cam_write) ) ) {
- // Raw sensor data only goes between camera and CPU
+ // Raw sensor data or Y16 only goes between camera and CPU
return -EINVAL;
}